@@ -10,6 +10,12 @@ options = (
         'help': 'Delete S3 objects on entity deletion',
         'group': 's3',
         'level': 2}),
+    ('s3-transaction-suffix-key', {
+        'type': 'yn',
+        'default': False,
+        'help': 'Add a temporary suffix to S3 keys during transaction',
+        'group': 's3',
+        'level': 2}),
     )
 
 
